diff libpurple/plugins/dbus-example.c @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 5205dd2bd035
line wrap: on
line diff
--- a/libpurple/plugins/dbus-example.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/plugins/dbus-example.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,22 +1,22 @@
 /*
  *   This is an example of a gaim dbus plugin.  After enabling this
  *   plugin, the following commands should work from the command line:
  *
- *   prompt$ gaim-send DbusExampleGetHelloObject
+ *   prompt$ purple-send DbusExampleGetHelloObject
  *
  *     returns, say: int32 74
  *
- *   prompt$ gaim-send DbusExampleGetText int32:74
+ *   prompt$ purple-send DbusExampleGetText int32:74
  *
  *     returns: string "Hello."
  *
- *   prompt$ gaim-send DbusExampleSetText int32:74 string:Bye!
+ *   prompt$ purple-send DbusExampleSetText int32:74 string:Bye!
  *
- *   prompt$ gaim-send DbusExampleGetText int32:74
+ *   prompt$ purple-send DbusExampleGetText int32:74
  *
  *     returns: string "Bye!"
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -52,38 +52,38 @@
 
 typedef struct {
 	char *text;
-} GaimText;
+} PurpleText;
 
-/* This makes the structure GaimText visible to the gaim-dbus type
-   system.  It defines GaimText as a type with no parent.  From now
+/* This makes the structure PurpleText visible to the purple-dbus type
+   system.  It defines PurpleText as a type with no parent.  From now
    on, we will be able to register pointers to structures of this
    type.  You to dbus-define types you want to be directly accessible
    by external applications. */
-GAIM_DBUS_DEFINE_TYPE(GaimText)
+PURPLE_DBUS_DEFINE_TYPE(PurpleText)
 
 /* Here we make four functions accessible to other applications by
-   DBus.  These functions can access types defined in gaim proper
-   (GaimBuddy) as well as the types defined in the plugin (GaimText).  */
-DBUS_EXPORT GaimText* dbus_example_get_hello_object(void);
-DBUS_EXPORT void dbus_example_set_text(GaimText *obj, const char *text);
-DBUS_EXPORT const char *dbus_example_get_text(GaimText *obj);
-DBUS_EXPORT const char *dbus_example_get_buddy_name(GaimBuddy *buddy);
+   DBus.  These functions can access types defined in purple proper
+   (PurpleBuddy) as well as the types defined in the plugin (PurpleText).  */
+DBUS_EXPORT PurpleText* dbus_example_get_hello_object(void);
+DBUS_EXPORT void dbus_example_set_text(PurpleText *obj, const char *text);
+DBUS_EXPORT const char *dbus_example_get_text(PurpleText *obj);
+DBUS_EXPORT const char *dbus_example_get_buddy_name(PurpleBuddy *buddy);
 
 /* This file has been generated by the #dbus-analize-functions.py
    script.  It contains dbus wrappers for the four functions declared
    above. */
 #include "dbus-example-bindings.c"
 
-/* This is the GaimText object we want to make publicly visible. */
-static GaimText hello;
+/* This is the PurpleText object we want to make publicly visible. */
+static PurpleText hello;
 
 /* Here come the definitions of the four exported functions. */
-GaimText* dbus_example_get_hello_object(void)
+PurpleText* dbus_example_get_hello_object(void)
 {
 	return &hello;
 }
 
-void dbus_example_set_text(GaimText *obj, const char *text)
+void dbus_example_set_text(PurpleText *obj, const char *text)
 {
 	if (obj != NULL) {
 		g_free(obj->text);
@@ -91,7 +91,7 @@
 	}
 }
 
-const char *dbus_example_get_text(GaimText *obj)
+const char *dbus_example_get_text(PurpleText *obj)
 {
 	if (obj != NULL)
 		return obj->text;
@@ -99,29 +99,29 @@
 		return NULL;
 }
 
-const char *dbus_example_get_buddy_name(GaimBuddy *buddy)
+const char *dbus_example_get_buddy_name(PurpleBuddy *buddy)
 {
-	return gaim_buddy_get_name(buddy);
+	return purple_buddy_get_name(buddy);
 }
 
 /* And now standard plugin stuff */
 
 static gboolean
-plugin_load(GaimPlugin *plugin)
+plugin_load(PurplePlugin *plugin)
 {
-	GAIM_DBUS_RETURN_FALSE_IF_DISABLED(plugin);
+	PURPLE_DBUS_RETURN_FALSE_IF_DISABLED(plugin);
 
 	/* First, we have to register our four exported functions with the
-	   main gaim dbus loop.  Without this statement, the gaim dbus
+	   main purple dbus loop.  Without this statement, the purple dbus
 	   code wouldn't know about our functions. */
-	GAIM_DBUS_REGISTER_BINDINGS(plugin);
+	PURPLE_DBUS_REGISTER_BINDINGS(plugin);
 
 	/* Then, we register the hello object of type GaimText.  Note that
 	   pointer registrations / unregistrations are completely dynamic;
 	   they don't have to be made when the plugin is loaded /
-	   unloaded.  Without this statement the dbus gaim code wouldn't
+	   unloaded.  Without this statement the dbus purple code wouldn't
 	   know about the hello object.  */
-	GAIM_DBUS_REGISTER_POINTER(&hello, GaimText);
+	PURPLE_DBUS_REGISTER_POINTER(&hello, PurpleText);
 
 	hello.text = g_strdup("Hello.");
 
@@ -130,26 +130,26 @@
 
 
 static gboolean
-plugin_unload(GaimPlugin *plugin)
+plugin_unload(PurplePlugin *plugin)
 {
 	g_free(hello.text);
 
 	/* It is necessary to unregister all pointers registered by the module. */
-	GAIM_DBUS_UNREGISTER_POINTER(&hello);
+	PURPLE_DBUS_UNREGISTER_POINTER(&hello);
 
 	return TRUE;
 }
 
-static GaimPluginInfo info =
+static PurplePluginInfo info =
 {
-	GAIM_PLUGIN_MAGIC,
-	GAIM_MAJOR_VERSION,
-	GAIM_MINOR_VERSION,
-	GAIM_PLUGIN_STANDARD,                             /**< type           */
+	PURPLE_PLUGIN_MAGIC,
+	PURPLE_MAJOR_VERSION,
+	PURPLE_MINOR_VERSION,
+	PURPLE_PLUGIN_STANDARD,                             /**< type           */
 	NULL,                                             /**< ui_requirement */
 	0,                                                /**< flags          */
 	NULL,                                             /**< dependencies   */
-	GAIM_PRIORITY_DEFAULT,                            /**< priority       */
+	PURPLE_PRIORITY_DEFAULT,                            /**< priority       */
 
 	"dbus-example",                                   /**< id             */
 	N_("DBus Example"),                               /**< name           */
@@ -159,7 +159,7 @@
 	                                                  /**  description    */
 	N_("DBus Plugin Example"),
 	"Piotr Zielinski (http://cl.cam.ac.uk/~pz215)",   /**< author         */
-	GAIM_WEBSITE,                                     /**< homepage       */
+	PURPLE_WEBSITE,                                     /**< homepage       */
 
 	plugin_load,                                      /**< load           */
 	plugin_unload,                                    /**< unload         */
@@ -171,8 +171,8 @@
 	NULL
 };
 
-static void init_plugin(GaimPlugin *plugin)
+static void init_plugin(PurplePlugin *plugin)
 {
 }
 
-GAIM_INIT_PLUGIN(dbus_example, init_plugin, info)
+PURPLE_INIT_PLUGIN(dbus_example, init_plugin, info)
@@ -1,22 +1,22 @@
 /*
- *   This is an example of a gaim dbus plugin.  After enabling this
+ *   This is an example of a purple dbus plugin.  After enabling this
  *   plugin, the following commands should work from the command line:
  *
@@ -1,22 +1,22 @@
  *     returns: string "Bye!"
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -99,29 +99,29 @@
 
-	/* Then, we register the hello object of type GaimText.  Note that
+	/* Then, we register the hello object of type PurpleText.  Note that
 	   pointer registrations / unregistrations are completely dynamic;
 	   they don't have to be made when the plugin is loaded /